@@ -8,82 +8,98 @@
 #include "charpick.h"
 
 
-/* This stuff assumes that this program is being run in an environment
- * that uses ISO-8859-1 (latin-1) as its native character code.
- */
 
 /* The comment for each char list has the html entity names of the chars */
+/* All gunicar codes should end in -1 */
+
 
 /* This is the default list used when starting charpick the first time */
 /* aacute, agrave, eacute, iacute, oacute, frac12, copy*/
-static const gchar *def_list = "";
+/* static const gchar *def_list = "áàéíñóœ©"; */
+static gunichar def_code[] = {225, 224, 233, 237, 241, 243, 189, 169, 1579, -1};
 
 /* aacute, agrave, acirc, atilde, auml. aring, aelig, ordf */
-static const gchar *a_list = "";
-static const gchar *cap_a_list = "ƪ";
+/* static const gchar *a_list = "áàâãäåæª"; */
+static gunichar a_code[] = {225, 224, 226, 227, 228, 229, 230, 170, -1};
+/* static const gchar *cap_a_list = "ÁÀÂÃÄÅÆª"; */
+static gunichar cap_a_code[] = {192, 193, 194, 195, 196, 197, 198, 170, -1}; 
 /* ccedil, cent, copy */
-static const gchar *c_list = "碩";
-static const gchar *cap_c_list = "Ǣ";
+/* static const gchar *c_list = "çÇ¢©"; */
+static gunichar c_code[] = {231, 199, 162, 169, -1};
 /* eacute, egrave, ecirc, euml, aelig */
-static const gchar *e_list = "";
-static const gchar *cap_e_list = "";
+/* static const gchar *e_list = "éèêëæ"; */
+static gunichar e_code[] = {232, 233, 234, 235, 230, -1};
+/* static const gchar *cap_e_list = "ÉÈÊËÆ"; */
+static gunichar cap_e_code[] = {200, 201, 202, 203, 198, -1};
 /* iacute, igrave, icirc, iuml */
-static const gchar *i_list = "";
-static const gchar *cap_i_list = "";
-/* */
-static const gchar *l_list = "";
-/* micro */
-static const gchar *m_list = "";
+/* static const gchar *i_list = "íìîï"; */
+static gunichar i_code[] = {236, 237, 238, 239, -1};
+/* static const gchar *cap_i_list = "ÍÌÎÏ"; */
+static gunichar cap_i_code[] = {204, 205, 206, 207, -1};
 /* ntilde (this is the most important line in this program.) */
-static const gchar *n_list = "";
-static const gchar *cap_n_list = "";
+/* static const gchar *n_list = "ñ, Ñ"; */
+static gunichar n_code[] = {241, 209, -1};
 /* oacute, ograve, ocirc, otilde, ouml, oslash, ordm */
-static const gchar *o_list = "";
-static const gchar *cap_o_list = "غ";
-/* para */
-static const gchar *p_list = "";
-/* reg */
-static const gchar *r_list = "";
+/* static const gchar *o_list = "óòôõöøº"; */
+static gunichar o_code[] = {242, 243, 244, 245, 246, 248, 176, -1};
+/* static const gchar *cap_o_list = "ÓÒÔÕÖØº"; */
+static gunichar cap_o_code[] = {210, 211, 212, 213, 214, 216, 176, -1};
 /* szlig, sect, dollar */
-static const gchar *s_list = "ߧ$";
+/* static const gchar *s_list = "ß§$"; */
+static gunichar s_code[] = {223, 167, 36, -1};
 /* eth, thorn */
-static const gchar *t_list = "";
-static const gchar *cap_t_list = "";
+/* static const gchar *t_list = "ðÐþÞ"; */
+static gunichar t_code[] = {240, 208, 254, 222, -1};
 /* uacute, ugrave, ucirc, uuml */
-static const gchar *u_list = "";
-static const gchar *cap_u_list = "";
+/* static const gchar *u_list = "úùûü"; */
+static gunichar u_code[] = {249, 250, 251, 252, -1};
+/* static const gchar *cap_u_list = "ÚÙÛÜ"; */
+static gunichar cap_u_code[] = {217, 218, 219, 220, -1};
 /* yacute, yuml, yen Yes, there is no capital yuml in iso 8859-1.*/
-static const gchar *y_list = "";
-static const gchar *cap_y_list = "";
+/* static const gchar *y_list = "ýÝÿ¥"; */
+static gunichar y_code[] = {253, 221, 255, 165, -1};
 
 /* extra characters unrelated to the latin alphabet. All characters in 
    ISO-8859-1 should now be accounted for.*/
-/* divide frac14 frac12 frac34 */
-static const gchar *slash_list = "";
 /* not shy macr plusmn */
-static const gchar *dash_list = "";
-/* plusmn */
-static const gchar *plus_list = "";
-/* cedil */
-static const gchar *comma_list = "";
-/* iquest */
-static const gchar *quest_list = "";
-/* iexcl */
-static const gchar *excl_list = "";
-/* brvbar */
-static const gchar *pipe_list = "";
+/* static const gchar *dash_list = "¬­¯±"; */
+static gunichar dash_code[] = {172, 173, 175, 177, -1};
 /* laquo raquo uml */
-static const gchar *quote_list = "";
-/* middot times */
-static const gchar *ast_list = "";
+/* static const gchar *quote_list = "«»š·×"; */
+static gunichar quote_code[] = {171, 187, 168, 183, 215, -1};
 /* curren, pound, yen, cent, dollar */
-static const gchar *currency_list = "$";
+/* static const gchar *currency_list = "€£¥¢$"; */
+static gunichar currency_code[] = {164, 163, 165, 162, 36, 8364, -1}; 
 /* sup1 frac12 */
-static const gchar *one_list = "";
-/* sup2 frac12 */
-static const gchar *two_list = "";
-/* sup3 frac34 */
-static const gchar *three_list = " ";
+/* static const gchar *one_list = "¹œŒ"; */
+static gunichar one_code[] = {185, 178, 179, 188, 189, 190, -1};
+/* µ ¶ ® ¿ |  */
+static gunichar misc_code[] = {181, 182, 174, 191, 124, -1};
+
+static const gunichar *chartable[] = {
+	def_code,
+	a_code,
+	cap_a_code,
+	c_code,
+	e_code,
+	cap_e_code,
+	i_code,
+	cap_i_code,
+	n_code,
+	o_code,
+	cap_o_code,
+	s_code,
+	t_code,
+	u_code,
+	cap_u_code,
+	y_code,
+	dash_code,
+	quote_code,
+	currency_code,
+	one_code,
+	misc_code
+};
+
 
 /* sets the picked character as the selection when it gets a request */
 static void
@@ -94,12 +110,13 @@ charpick_selection_handler(GtkWidget *widget,
 		           gpointer data)
 {
   charpick_data *p_curr_data = data;
+  gint num;
+  gchar tmp[7];
+  num = g_unichar_to_utf8 (p_curr_data->selected_unichar, tmp);
+  tmp[num] = '\0';
+  
+  gtk_selection_data_set_text (selection_data, tmp, -1);
 
-  gtk_selection_data_set(selection_data,
-			 GDK_SELECTION_TYPE_STRING,
-			 8,
-			 &p_curr_data->selected_char,
-			 1);
   return;
 }
 
@@ -119,6 +136,24 @@ selection_clear_cb (GtkWidget *widget, GdkEventSelection *event,
   return TRUE;
 }
 
+static gchar *
+get_utf_string (gunichar *codes)
+{
+	gchar *string = NULL, tmp[7];
+	gint i = 0;
+	while (codes[i] != -1) {
+		gint num;
+		num = g_unichar_to_utf8 (codes[i], tmp);
+		tmp[num] = 0;
+		if (string) 
+			string = g_strconcat (string, tmp, NULL);
+		else
+			string = g_strdup (tmp);
+		i++;
+	}
+	return string;
+}
+
 static gint
 toggle_button_toggled_cb(GtkToggleButton *button, gpointer data)
 {
@@ -133,14 +168,15 @@ toggle_button_toggled_cb(GtkToggleButton *button, gpointer data)
 
   if (toggled)
   { 
+    gunichar unichar;
     if (curr_data->last_toggle_button && (button != curr_data->last_toggle_button))
     	gtk_toggle_button_set_active (curr_data->last_toggle_button,
     				      FALSE);
     				      
     curr_data->last_toggle_button = button; 
     gtk_widget_grab_focus(curr_data->applet);
-    /* set selected_char */
-    curr_data->selected_char = curr_data->charlist[button_index];
+    unichar = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (button), "unichar"));
+    curr_data->selected_unichar = unichar;
     /* set this? widget as the selection owner */
     gtk_selection_owner_set (curr_data->applet,
 	  		     GDK_SELECTION_PRIMARY,
@@ -175,97 +211,159 @@ static gint
 key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
   charpick_data *p_curr_data = data;
+  gint *code = NULL;
   gchar inputchar = event->keyval;
 
   switch (inputchar)
     {
-    case 'a' : p_curr_data->charlist = a_list;
+    case 'a' : code = a_code;
                break;
-    case 'A' : p_curr_data->charlist = cap_a_list;
+    case 'A' : code = cap_a_code;
                break;
-    case 'c' : p_curr_data->charlist = c_list;
+    case 'c' : 
+    case 'C' : code = c_code;
                break;
-    case 'C' : p_curr_data->charlist = cap_c_list;
+    case 'e' : code = e_code;
                break;
-    case 'e' : p_curr_data->charlist = e_list;
+    case 'E' : code = cap_e_code;
                break;
-    case 'E' : p_curr_data->charlist = cap_e_list;
+    case 'i' : code = i_code;
                break;
-    case 'i' : p_curr_data->charlist = i_list;
+    case 'I' : code =  cap_i_code;
                break;
-    case 'I' : p_curr_data->charlist = cap_i_list;
+    case 'n' : 
+    case 'N' : code = n_code;
                break;
-    case 'l' : p_curr_data->charlist = l_list;
+    case 'o' : code = o_code;
                break;
-    case 'm' : p_curr_data->charlist = m_list;
+    case 'O' : code = cap_o_code;
                break;
-    case 'n' : p_curr_data->charlist = n_list;
+    case 's' : code = s_code;
                break;
-    case 'N' : p_curr_data->charlist = cap_n_list;
+    case 't' : 
+    case 'T' : code = t_code;
                break;
-    case 'o' : p_curr_data->charlist = o_list;
+    case 'u' : code = u_code;
                break;
-    case 'O' : p_curr_data->charlist = cap_o_list;
+    case 'U' : code = cap_u_code;
                break;
-    case 'p' : p_curr_data->charlist = p_list;
+    case 'y' : 
+    case 'Y' : code = y_code;
                break;
-    case 'r' : p_curr_data->charlist = r_list;
+    case '-' : code = dash_code;
                break;
-    case 's' : p_curr_data->charlist = s_list;
+    case '\"' : code = quote_code;
                break;
-    case 't' : p_curr_data->charlist = t_list;
+    case '$' : code = currency_code;
                break;
-    case 'T' : p_curr_data->charlist = cap_t_list;
+    case '1' : 
+    case '2' :
+    case '3' : code = one_code;
                break;
-    case 'u' : p_curr_data->charlist = u_list;
-               break;
-    case 'U' : p_curr_data->charlist = cap_u_list;
-               break;
-    case 'y' : p_curr_data->charlist = y_list;
-               break;
-    case 'Y' : p_curr_data->charlist = cap_y_list;
-               break;
-    case '/' : p_curr_data->charlist = slash_list;
-               break;
-    case '-' : p_curr_data->charlist = dash_list;
-               break;
-    case '+' : p_curr_data->charlist = plus_list;
-               break;
-    case ',' : p_curr_data->charlist = comma_list;
-               break;
-    case '?' : p_curr_data->charlist = quest_list;
-               break;
-    case '!' : p_curr_data->charlist = excl_list;
-               break;
-    case '|' : p_curr_data->charlist = pipe_list;
-               break;
-    case '\"' : p_curr_data->charlist = quote_list;
-               break;
-    case '*' : p_curr_data->charlist = ast_list;
-               break;
-    case '$' : p_curr_data->charlist = currency_list;
-               break;
-    case '' : p_curr_data->charlist = currency_list;
-               break;
-    case '' : p_curr_data->charlist = currency_list;
-               break;
-    case '1' : p_curr_data->charlist = one_list;
-               break;
-    case '2' : p_curr_data->charlist = two_list;
-               break;
-    case '3' : p_curr_data->charlist = three_list;
-               break;
-    case 'd' : p_curr_data->charlist = 
-               p_curr_data->default_charlist;
+    case 'd' : code = NULL;
                break;
     default :
     		return FALSE;
     }
-
+#if 0
+  if (code)
+    p_curr_data->charlist = get_utf_string (code);
+  else
+    p_curr_data->charlist = "hello";
   p_curr_data->last_index = NO_LAST_INDEX;
   p_curr_data->last_toggle_button = NULL;
   build_table(p_curr_data);
-  return TRUE;
+#endif
+  return FALSE;
+}
+
+static void
+menuitem_activated (GtkMenuItem *menuitem, charpick_data *curr_data)
+{
+	gchar *string;
+	PanelApplet *applet = PANEL_APPLET (curr_data->applet);
+	
+	string = g_object_get_data (G_OBJECT (menuitem), "string");
+	if (g_ascii_strcasecmp (curr_data->charlist, string) == 0)
+		return;
+	
+	curr_data->charlist = string;
+	build_table (curr_data);
+	panel_applet_gconf_set_string (applet, "current_list", curr_data->charlist, NULL);
+}
+
+void
+populate_menu (charpick_data *curr_data)
+{
+	GList *list = curr_data->chartable;
+	GSList *group = NULL;
+	GtkMenu *menu;
+	GtkWidget *menuitem;
+
+	if (curr_data->menu)
+		gtk_widget_destroy (curr_data->menu);
+
+	curr_data->menu = gtk_menu_new ();
+	menu  = GTK_MENU (curr_data->menu);
+	
+	while (list) {
+		gchar *string = list->data;
+		menuitem = gtk_radio_menu_item_new_with_label (group, string);
+		group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (menuitem));
+		gtk_widget_show (menuitem);
+		g_object_set_data (G_OBJECT (menuitem), "string", string);
+		g_signal_connect (G_OBJECT (menuitem), "activate",
+				   G_CALLBACK (menuitem_activated), curr_data);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		if (g_ascii_strcasecmp (curr_data->charlist, string) == 0)
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), TRUE);
+		list = g_list_next (list);
+	}
+	
+}
+
+static void
+get_menu_pos (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer data)
+{
+	charpick_data *curr_data = data;
+	GtkRequisition  reqmenu, reqapplet;
+	gint tempx, tempy, width, height;
+	gint screen_width, screen_height;
+	
+	gtk_widget_size_request (GTK_WIDGET (menu), &reqmenu);
+	gdk_window_get_origin (GTK_WIDGET (curr_data->applet)->window, &tempx, &tempy);
+     	gdk_window_get_geometry (GTK_WIDGET (curr_data->applet)->window, NULL, NULL,
+     			      &width, &height, NULL);
+     			      
+     	switch (panel_applet_get_orient (PANEL_APPLET (curr_data->applet))) {
+     	case PANEL_APPLET_ORIENT_DOWN:
+        	tempy += height;
+     		break;
+     	case PANEL_APPLET_ORIENT_UP:
+        	tempy -= reqmenu.height;
+     		break;
+     	case PANEL_APPLET_ORIENT_LEFT:
+     		tempx -= reqmenu.width;
+		break;
+     	case PANEL_APPLET_ORIENT_RIGHT:
+     		tempx += width;
+		break;
+     	}
+	screen_width = gdk_screen_width ();
+     	screen_height = gdk_screen_height ();
+     	*x = CLAMP (tempx, 0, MAX (0, screen_width - reqmenu.width));
+     	*y = CLAMP (tempy, 0, MAX (0, screen_height - reqmenu.height));
+}
+
+static void
+chooser_button_clicked (GtkButton *button, charpick_data *curr_data)
+{
+	if (GTK_WIDGET_VISIBLE (curr_data->menu))
+		gtk_menu_popdown (GTK_MENU (curr_data->menu));
+	else
+		gtk_menu_popup (GTK_MENU (curr_data->menu), NULL, NULL, get_menu_pos, curr_data,
+					    0, gtk_get_current_event_time());
+					    
 }
 
 /* creates table of buttons, sets up their callbacks, and packs the table in
@@ -276,56 +374,83 @@ build_table(charpick_data *p_curr_data)
 {
   GtkWidget *box;
   GtkWidget *toggle_button;
+  GtkWidget *button, *arrow;
+  GtkTooltips *tooltips;
   gint size;
-  gint i, num;
+  gint i = 0, len;
+  gchar *charlist;
+  gint width, height;
   
   if (p_curr_data->box)
     gtk_widget_destroy(p_curr_data->box);
   if (p_curr_data->panel_vertical == TRUE)
     box = gtk_vbox_new (TRUE, 0);
-  else
+  else 
     box = gtk_hbox_new (TRUE, 0);
   gtk_widget_show (box);
   p_curr_data->box = box;
-  num = strlen (p_curr_data->charlist);
+  tooltips = gtk_tooltips_new ();
+  button = gtk_button_new ();
 
-  for (i=0; i < num; i++) {
-    gchar *str_utf8;
-    gchar currstr[2];
-    currstr[0] = p_curr_data->charlist[i];
-    currstr[1] = '\0';
- 
-    str_utf8 = g_convert (currstr, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
-    toggle_button = gtk_toggle_button_new_with_label (str_utf8);
-    g_free (str_utf8);
+  gtk_tooltips_set_tip (tooltips, button, _("Available palettes"), NULL);
+  switch (panel_applet_get_orient (PANEL_APPLET (p_curr_data->applet))) {
+     	case PANEL_APPLET_ORIENT_DOWN:
+        	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT);  ;
+     		break;
+     	case PANEL_APPLET_ORIENT_UP:
+        	arrow = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);  
+     		break;
+     	case PANEL_APPLET_ORIENT_LEFT:
+     		arrow = gtk_arrow_new (GTK_ARROW_LEFT, GTK_SHADOW_OUT);  
+		break;
+     	case PANEL_APPLET_ORIENT_RIGHT:
+     		arrow = gtk_arrow_new (GTK_ARROW_RIGHT, GTK_SHADOW_OUT);  
+		break;
+  }
+  gtk_container_add (GTK_CONTAINER (button), arrow);
+  gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE, 0);
+  g_signal_connect (G_OBJECT (button), "clicked",
+                            G_CALLBACK (chooser_button_clicked), p_curr_data);
+  g_signal_connect (G_OBJECT (button), "button_press_event",
+                             G_CALLBACK (button_press_hack), p_curr_data->applet);
+
+  len = g_utf8_strlen (p_curr_data->charlist, -1);
+  charlist = g_strdup (p_curr_data->charlist);
+  for (i = 0; i < len; i++) {
+    gchar label[7];
+    gint num;
+    g_utf8_strncpy (label, charlist, 1);
+    charlist = g_utf8_next_char (charlist);
+   
+    toggle_button = gtk_toggle_button_new_with_label (label);
     gtk_box_pack_start (GTK_BOX (box), toggle_button, TRUE, TRUE, 0);
     gtk_button_set_relief(GTK_BUTTON(toggle_button), GTK_RELIEF_NONE);
-    g_object_set_data (G_OBJECT (toggle_button), "index", GINT_TO_POINTER (i));
+    gtk_tooltips_set_tip (tooltips, toggle_button, 
+                      _("Insert special characters"), NULL);
+  
+    g_object_set_data (G_OBJECT (toggle_button), "unichar", 
+				GINT_TO_POINTER(g_utf8_get_char (label)));
     gtk_signal_connect (GTK_OBJECT (toggle_button), "toggled",
                         (GtkSignalFunc) toggle_button_toggled_cb,
                         p_curr_data);
     gtk_signal_connect (GTK_OBJECT (toggle_button), "button_press_event", 
                         (GtkSignalFunc) button_press_hack, p_curr_data->applet);
   }
-
-  gtk_container_add (GTK_CONTAINER(p_curr_data->frame), box);
-  gtk_widget_show_all (p_curr_data->frame);
   
-  /* a fudge factor is applied to make less space wasted.
-     this is needed now that we have capital letters and the new 
-     2 x 4 default layout with larger cells that required.
-     The right thing to do would be to make width of cells setable
-     seperately from height, or to make aspect ratio setable.
-   */  
-#if 0
-  gtk_widget_set_usize(table, 
-                       ((cols * size * 2) / 3), 
-                       (rows * size));
+ 
+  
+  gtk_container_add (GTK_CONTAINER(p_curr_data->applet), box);
+  gtk_widget_show_all (p_curr_data->box);
 
-#endif
+  if (p_curr_data->panel_vertical == TRUE)
+     gtk_widget_set_size_request (box, p_curr_data->panel_size,  -1);
+  else
+     gtk_widget_set_size_request (box, -1, p_curr_data->panel_size+5);
 
   p_curr_data->last_index = NO_LAST_INDEX;
   p_curr_data->last_toggle_button = NULL;
+  
+  
 }
 
 static void applet_change_pixel_size(PanelApplet *applet, gint size, gpointer data)
@@ -364,6 +489,7 @@ about (BonoboUIComponent *uic,
 	  /* If your charset supports it, please use U00F1 to replace the "n"
 	   * in "Muniz". */
 	  _("Alexandre Muniz <munizao@xprt.net>"),
+	  _("Kevin Vandersloot"),
 	  NULL
   };
 
@@ -390,7 +516,7 @@ about (BonoboUIComponent *uic,
   }
   
   about_box = gnome_about_new (_("Character Palette"),
-			       CHARPICK_VERSION,
+			       VERSION,
 			       _("Copyright (C) 1998"),
 			       _("Gnome Panel applet for selecting strange "
 			         "characters that are not on my keyboard. "
@@ -422,9 +548,10 @@ help_cb (BonoboUIComponent *uic,
 {
   GError *error = NULL;
 
-  egg_screen_help_display (
+  egg_help_display_on_screen (
+		"char-palette", NULL,
 		gtk_widget_get_screen (curr_data->applet),
-		"char-palette", NULL, &error);
+		&error);
 
   if (error) { /* FIXME: the user needs to see this */
     g_warning ("help error: %s\n", error->message);
@@ -437,21 +564,10 @@ static void
 applet_destroy (GtkWidget *widget, gpointer data)
 {
   charpick_data *curr_data = data;
-  GtkTooltips *tooltips;
   GtkWidget *applet = curr_data->applet;
 
   g_return_if_fail (curr_data);
-  
-  if (curr_data->default_charlist)
-      g_free (curr_data->default_charlist);
-  curr_data->default_charlist = NULL;
-  
-  tooltips = g_object_get_data (G_OBJECT (applet), "tooltips");
-  if (tooltips) {
-      g_object_unref (tooltips);
-      g_object_set_data (G_OBJECT (applet), "tooltips", NULL);
-  }
-  
+   
   if (curr_data->propwindow)
     gtk_widget_destroy (curr_data->propwindow);
 
@@ -459,6 +575,65 @@ applet_destroy (GtkWidget *widget, gpointer data)
   
 }
 
+void 
+save_chartable (charpick_data *curr_data)
+{
+	PanelApplet *applet = PANEL_APPLET (curr_data->applet);
+	GConfValue *value;
+	GList *list = curr_data->chartable;
+	GSList *slist = NULL;
+	
+	while (list) {
+		gchar *charlist = list->data;
+		GConfValue *v1;
+		v1 = gconf_value_new_from_string (GCONF_VALUE_STRING, charlist, NULL);
+		slist = g_slist_append (slist, v1);
+		list = g_list_next (list);
+	}
+	
+	value = gconf_value_new (GCONF_VALUE_LIST);
+	gconf_value_set_list_type (value, GCONF_VALUE_STRING);
+	gconf_value_set_list_nocopy (value, slist);
+	panel_applet_gconf_set_value (applet, "chartable", value, NULL);
+	gconf_value_free (value);
+}
+
+static void
+get_chartable (charpick_data *curr_data)
+{
+	PanelApplet *applet = PANEL_APPLET (curr_data->applet);
+	GConfValue *value;
+	gint i, n;
+	
+	value = panel_applet_gconf_get_value (applet, "chartable", NULL);
+	if (value) {
+		GSList *slist = gconf_value_get_list (value);
+		while (slist) {
+			GConfValue *v1 = slist->data;
+			gchar *charlist;
+			
+			charlist = g_strdup (gconf_value_get_string (v1));
+			curr_data->chartable = g_list_append (curr_data->chartable, charlist);
+			
+			slist = g_slist_next (slist);
+		}
+		gconf_value_free (value);
+	}
+	else {
+		n = G_N_ELEMENTS (chartable);
+		for (i=0; i<n; i++) {
+			gchar *string;
+		
+			string = get_utf_string ((gunichar *)chartable[i]);
+			curr_data->chartable = g_list_append (curr_data->chartable, string);
+		
+		}
+		save_chartable (curr_data);
+	}
+	
+
+}
+
 static const BonoboUIVerb charpick_applet_menu_verbs [] = {
         BONOBO_UI_UNSAFE_VERB ("Preferences", show_preferences_dialog),
         BONOBO_UI_UNSAFE_VERB ("Help",        help_cb),
@@ -483,13 +658,6 @@ set_atk_name_description (GtkWidget *widget, const gchar *name,
 static void
 make_applet_accessible (GtkWidget *applet)
 {
-  GtkTooltips *tooltips;
-  tooltips = gtk_tooltips_new ();
-  g_object_ref (tooltips);
-  gtk_object_sink (GTK_OBJECT (tooltips));
-  g_object_set_data (G_OBJECT (applet), "tooltips", tooltips); 
-  gtk_tooltips_set_tip (tooltips, applet, 
-                      _("Insert special characters"), NULL);
   set_atk_name_description (applet, _("Character Palette"), NULL);
 }
 
@@ -497,48 +665,49 @@ static gboolean
 charpicker_applet_fill (PanelApplet *applet)
 {
   charpick_data *curr_data;
-  gchar *default_charlist_utf8;
+  GdkAtom utf8_atom;
+  GList *list;
+  gchar *string;
   
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/charpick.png");
   
   panel_applet_add_preferences (applet, "/schemas/apps/charpick/prefs", NULL);
    
   curr_data = g_new0 (charpick_data, 1);
-  curr_data->selected_char = ' ';
   curr_data->last_index = NO_LAST_INDEX;
   curr_data->applet = GTK_WIDGET (applet);
   
-  default_charlist_utf8 = panel_applet_gconf_get_string (applet, 
-  							 "default_list", NULL);
-  if (!default_charlist_utf8)
-    curr_data->default_charlist = g_strdup (def_list);
-  else {
-    curr_data->default_charlist = g_convert (default_charlist_utf8, -1, 
-    					     "ISO-8859-1", "UTF-8", 
-  					      NULL, NULL, NULL);
-    g_free (default_charlist_utf8);
-  }
-    
-  curr_data->charlist = curr_data->default_charlist;
-
-  /* Create table */
-  curr_data->frame = gtk_frame_new (NULL);
-  gtk_container_add (GTK_CONTAINER (curr_data->applet), curr_data->frame);
+  get_chartable (curr_data);
+  
+  string  = panel_applet_gconf_get_string (applet, 
+  							     "current_list", NULL);
+  if (string) {
+  	list = curr_data->chartable;
+  	while (list) {
+  		if (g_ascii_strcasecmp (list->data, string) == 0)
+  			curr_data->charlist = list->data;
+  		list = g_list_next (list);
+  	}
+  	g_free (string);
+  } 
+  else
+  	curr_data->charlist = curr_data->chartable->data;  
+ 
+  curr_data->panel_size = panel_applet_get_size (applet);
+  
   build_table (curr_data);
-  
-  gtk_frame_set_shadow_type (GTK_FRAME(curr_data->frame), GTK_SHADOW_IN);
-
-  
-  gtk_signal_connect (GTK_OBJECT (curr_data->applet), "key_press_event",
-		      (GtkSignalFunc) key_press_event, curr_data);
+    
+  g_signal_connect (G_OBJECT (curr_data->applet), "key_press_event",
+		             G_CALLBACK (key_press_event), curr_data);
 
+  utf8_atom = gdk_atom_intern ("UTF8_STRING", FALSE);
   gtk_selection_add_target (curr_data->applet, 
 			    GDK_SELECTION_PRIMARY,
-                            GDK_SELECTION_TYPE_STRING,
+                            utf8_atom,
 			    0);
   gtk_selection_add_target (curr_data->applet, 
 			    GDK_SELECTION_CLIPBOARD,
-                            GDK_SELECTION_TYPE_STRING,
+                            utf8_atom,
 			    0);
   gtk_signal_connect (GTK_OBJECT (curr_data->applet), "selection_get",
 		      GTK_SIGNAL_FUNC (charpick_selection_handler),
@@ -567,7 +736,9 @@ charpicker_applet_fill (PanelApplet *applet)
                                      NULL,
 			             charpick_applet_menu_verbs,
 			             curr_data);
-
+			             
+  populate_menu (curr_data);
+  
   return TRUE;
 }
 
