@@ -132,14 +132,18 @@ struct _GKB
   GtkWidget *darea_frame;
   GtkWidget *image;
   GtkWidget *addwindow;
+  GtkWidget *propwindow;
   GtkTooltips *tooltips;
 
   gint n;
   gint cur;
 
-  gchar *key;
+  gchar *key, *old_key;
   guint keysym, state;
+  gint keycode;
+  guint old_keysym, old_state;
 
+  guint button_press_id;
 };
 
 struct _GkbKeymapWg
@@ -168,6 +172,8 @@ struct _GkbKeymapWg
   GtkWidget *newkeymap, *delkeymap;
 };
 
+#define GKB_SMALL_PANEL_SIZE 25 /* less than */
+
 /* gkb.c */
 void gkb_update (GKB *gkb, gboolean set_command);
 void alert (const gchar * str);
@@ -190,7 +196,7 @@ GkbKeymap * loadprop (GKB *gkb, int i);
 
 /* prop-list.c */
 GtkWidget * gkb_prop_create_buttons_vbox (GkbPropertyBoxInfo *pbi);
-GtkWidget * gkb_prop_create_scrolled_window (GkbPropertyBoxInfo *pbi);
+GtkWidget * gkb_prop_create_scrolled_window (GkbPropertyBoxInfo *pbi, GtkWidget *label);
        void gkb_prop_list_reload (GkbPropertyBoxInfo *pbi);
 
 /* system.c */
@@ -260,6 +266,8 @@ gboolean gconf_applet_get_bool  (PanelApplet *parent,
 /* Globals */
 gchar * prefixdir;
 
+void gkb_update_handlers (GKB *gkb, gboolean disconnect);
+
 G_BEGIN_DECLS
 
 gboolean fill_gkb_applet(PanelApplet *applet);
