@@ -43,6 +43,7 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+#include <libgnome/libgnome.h>
 #include <libgnomeui/gnome-about.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <panel-applet.h>
@@ -95,26 +96,53 @@
 
 #define VOLUME_DEFAULT_ICON_SIZE 48
 static GtkIconSize volume_icon_size = 0;
+static gboolean icons_initialized = FALSE;
+static gboolean device_present = TRUE;
 
 #define IS_PANEL_HORIZONTAL(o) (o == PANEL_APPLET_ORIENT_UP || o == PANEL_APPLET_ORIENT_DOWN)
 
+#ifdef OSS_API
+
+typedef struct {
+	gint channel;
+	gchar *name;
+} ChannelData;
+
+static gchar *channel_names [] = {
+	N_("Main Volume"), N_("Bass"), N_("Treble"), N_("Synth"), 
+	N_("Pcm"), N_("Speaker"), N_("Line"), 
+	N_("Microphone"), N_("CD"), N_("Mix"), N_("Pcm2"), 
+	N_("Recording Level"), N_("Input Gain"), N_("Output Gain"), 
+	N_("Line1"), N_("Line2"), N_("Line3"), N_("Digital1"), 
+	N_("Digital2"), N_("Digital3"), 
+	N_("Phone Input"), N_("Phone Output"), N_("Video"), N_("Radio"), N_("Monitor")
+};
+#endif
+
 typedef struct {
 	PanelAppletOrient  orientation;
 
 	gint               timeout;
-	gboolean           mute;
+	gboolean       mute;
 	gint               vol;
 	gint               vol_before_popup;
+	gint		    channel;
+	int 		    mixerchannel;
+	GList		    *channels;
+	gchar		    *device;
 
 	GtkAdjustment     *adj;
 
 	GtkWidget         *applet;
 	GtkWidget         *frame;
 	GtkWidget         *image;
+	GtkWidget 		*prefdialog;
 	
 	/* The popup window and scale. */
 	GtkWidget         *popup;
 	GtkWidget         *scale;
+	
+	GtkWidget 		*error_dialog;
 
 	GdkPixbuf	  *zero;
 	GdkPixbuf	  *min;
@@ -141,11 +169,9 @@ static gchar *run_mixer_cmd = NULL;
 
 static const gchar *access_name = N_("Volume Control");     
 static const gchar *access_name_mute = N_("Volume Control (muted)");
+static const gchar *access_name_nodevice = N_("No audio device");
 gboolean gail_loaded = FALSE;  
 
-#ifdef OSS_API
-static int mixerchannel;
-#endif
 
 #ifdef IRIX_API
 /*
@@ -158,15 +184,48 @@ long pv_buf[MAX_PV_BUF] = {
 };
 #endif
 
+#ifdef OSS_API
+static void
+get_channels (MixerData *data)
+{
+	gint res, i;
+	int devmask;
+	gboolean valid = FALSE;
+	
+	res = ioctl(mixerfd, MIXER_READ(SOUND_MIXER_DEVMASK), &devmask);
+	if (res != 0) {
+		return;
+	} 
+	for (i = 0; i < SOUND_MIXER_NRDEVICES; i++) {
+		ChannelData *cdata;
+		if (devmask & (1 << i)) {
+			cdata = g_new0 (ChannelData, 1);
+			cdata->channel = i;
+			cdata->name = channel_names[i];
+			data->channels = g_list_append (data->channels, cdata);
+			if (data->mixerchannel == i)
+				valid = TRUE;
+		}
+	}
+	/* selected channel does not work. Set it to something that does */
+	if (!valid) {
+		ChannelData *cdata = data->channels->data;
+		data->mixerchannel = cdata->channel;
+		panel_applet_gconf_set_int (PANEL_APPLET (data->applet), "channel", 
+							  data->mixerchannel, NULL);
+	}
+}
+#endif
+
 /********************** Mixer related Code *******************/
 /*  Mostly based on the gmix code                            */
 /*************************************************************/
 static gboolean
-openMixer(const gchar *device_name ) 
+openMixer(const gchar *device_name, MixerData *data) 
 {
 	gint res, ver;
 #ifdef OSS_API
-	int devmask;
+	
 
 	mixerfd = open(device_name, O_RDWR, 0);
 #endif
@@ -201,37 +260,22 @@ openMixer(const gchar *device_name )
 	 * Check whether this mixer actually supports the channel
 	 * we're going to try to monitor.
 	 */
-	res = ioctl(mixerfd, MIXER_READ(SOUND_MIXER_DEVMASK), &devmask);
-	if (res != 0) {
-		char *s = g_strdup_printf(_("Querying available channels of mixer device %s failed\n"), device_name);
-		gnome_error_dialog(s);
-		g_free(s);
-		return TRUE;
-	} else if (devmask & SOUND_MASK_VOLUME) {
-		mixerchannel = SOUND_MIXER_VOLUME;
-	} else if (devmask & SOUND_MASK_PCM) {
-		g_message(_("warning: mixer has no volume channel - using PCM instead.\n"));
-		mixerchannel = SOUND_MIXER_PCM;
-	} else {
-		char *s = g_strdup_printf(_("Mixer device %s has neither volume nor PCM channels.\n"), device_name);
-		gnome_error_dialog(s);
-		g_free(s);
-		return TRUE;
-	}
+	 get_channels (data);
+
 #endif	
  	return TRUE;	
 }
 
 /* only works with master vol currently */
 static int
-readMixer(void)
+readMixer(MixerData *data)
 {
 	gint vol, r, l;
 #ifdef OSS_API
 	/* if we couldn't open the mixer */
 	if (mixerfd < 0) return 0;
 
-	ioctl(mixerfd, MIXER_READ(mixerchannel), &vol);
+	ioctl(mixerfd, MIXER_READ(data->mixerchannel), &vol);
 
 	l = vol & 0xff;
 	r = (vol & 0xff00) >> 8;
@@ -256,7 +300,7 @@ readMixer(void)
 }
 
 static void
-setMixer(gint vol)
+setMixer(gint vol, MixerData *data)
 {
 	gint tvol;
 #ifdef OSS_API
@@ -265,9 +309,13 @@ setMixer(gint vol)
 
 	tvol = (vol << 8) + vol;
 /*g_message("Saving mixer value of %d",tvol);*/
-	ioctl(mixerfd, MIXER_WRITE(mixerchannel), &tvol);
+	ioctl(mixerfd, MIXER_WRITE(data->mixerchannel), &tvol);
+	
+/* SOUND_MIXER_SPEAKER is output level on Mac, but input level on PC. #96639 */
+#ifdef __powerpc__
 	ioctl(mixerfd, MIXER_WRITE(SOUND_MIXER_SPEAKER), &tvol);
 #endif
+#endif
 #ifdef SUN_API
  	audio_info_t ainfo;
 	AUDIO_INITINFO (&ainfo);
@@ -299,18 +347,103 @@ mixer_value_changed_cb (GtkAdjustment *adj, MixerData *data)
 	mixer_update_image (data);
 
 	if (!data->mute) {
-		setMixer (vol);
+		setMixer (vol, data);
 	}
 }
 
+#ifdef SUN_API
+static gboolean
+set_mute_status (gboolean mute_state)
+{
+	audio_info_t ainfo;
+	AUDIO_INITINFO (&ainfo);
+	ainfo.output_muted = mute_state;
+	ioctl (mixerfd, AUDIO_SETINFO, &ainfo);
+}
+
+static gboolean
+get_mute_status ()
+{
+	audio_info_t ainfo;
+	AUDIO_INITINFO (&ainfo);
+	ioctl (mixerfd, AUDIO_GETINFO, &ainfo);
+	return (ainfo.output_muted);
+}
+#endif
+
 static gboolean
 mixer_timeout_cb (MixerData *data)
 {
 	BonoboUIComponent *component;
 	gint               vol;
+	gboolean state;
 
-	vol = readMixer ();
+	if (!device_present) {
+		data->mute = TRUE;
+		mixer_update_image (data);
 
+		gtk_tooltips_set_tip (data->tooltips,
+				      data->applet,
+				      _(access_name_nodevice),
+				      NULL);
+		if (gail_loaded) {
+			add_atk_namedesc (data->applet,
+					  _(access_name_nodevice),
+					  NULL);
+		}
+		return TRUE;
+	}
+
+#ifdef SUN_API
+	state = get_mute_status ();
+
+	if (state != data->mute) {
+		data->mute = state;
+		if (data->mute) {
+			mixer_update_image (data);
+
+
+			gtk_tooltips_set_tip (data->tooltips,
+					      data->applet,
+					      _(access_name_mute),
+					      NULL);
+			if (gail_loaded) {
+				add_atk_namedesc (data->applet,
+						  _(access_name_mute),
+						  NULL);
+			}
+			component = panel_applet_get_popup_component (PANEL_APPLET (data->applet));
+			bonobo_ui_component_set_prop (component,
+						      "/commands/Mute",
+						      "state",
+						      "1",
+						      NULL);
+
+		} else {
+			mixer_update_image (data);
+
+			gtk_tooltips_set_tip (data->tooltips,
+					      data->applet,
+					      _(access_name),
+					      NULL);
+			if (gail_loaded) {
+				add_atk_namedesc (data->applet,
+						  _(access_name),
+						  NULL);
+			}
+			component = panel_applet_get_popup_component (PANEL_APPLET (data->applet));
+			bonobo_ui_component_set_prop (component,
+						      "/commands/Mute",
+						      "state",
+						      "0",
+						      NULL);
+
+		}
+	}
+#endif
+	vol = readMixer (data);
+
+#ifndef SUN_API
 	/* Some external program changed the volume, get out of mute mode. */
 	if (data->mute && (vol > 0)) {
 		data->mute = FALSE;
@@ -332,6 +465,7 @@ mixer_timeout_cb (MixerData *data)
 			add_atk_namedesc (data->applet, _(access_name), NULL);
 		}
 	}
+#endif
 
 	if (!data->mute && vol != data->vol) {
 		data->vol = vol;
@@ -447,6 +581,36 @@ scale_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *data
 
 	return FALSE;
 }
+
+static void
+error_response (GtkDialog *dialog, gint id, MixerData *data)
+{
+	gtk_widget_destroy (data->error_dialog);
+	data->error_dialog = NULL;
+}
+
+static void
+show_error_dialog (MixerData *data)
+{	
+	if (data->error_dialog) {
+		gtk_window_present (GTK_WINDOW (data->error_dialog));
+		return;
+	}
+	data->error_dialog = gtk_message_dialog_new (NULL,
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+					 ("Couldn't open mixer device %s\n"),
+					 data->device, NULL);
+
+	gtk_window_set_screen (GTK_WINDOW (data->error_dialog),
+			       gtk_widget_get_screen (GTK_WIDGET (data->applet)));
+	g_signal_connect (GTK_OBJECT (data->error_dialog), 
+                             "response", 
+                             G_CALLBACK (error_response),
+                             data);
+        gtk_widget_show_all (data->error_dialog);
+}
+
 static gboolean
 scale_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerData *data)
 {
@@ -459,14 +623,22 @@ scale_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerDa
 	return FALSE;
 }
 
+static gboolean
+scale_button_event  (GtkWidget *widget, GdkEventButton *event, MixerData *data)
+{
+	return TRUE;
+}
+
 static gboolean
 applet_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerData *data)
 {
+
 	if (event->button == 1) {
-		if (data->popup == NULL) {
+		if (data->popup == NULL && device_present) {
 			mixer_popup_show (data);
 			return TRUE;
-		}
+		} else if (!device_present)
+			show_error_dialog (data);
 	}
 
 	return FALSE;
@@ -490,8 +662,10 @@ applet_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *dat
 		/* Apply. */
 		if (data->popup != NULL)
 			mixer_popup_hide (data, FALSE);
-		else
+		else if(device_present)
 			mixer_popup_show (data);
+		else
+			show_error_dialog (data);
 		return TRUE;
 
 	default:
@@ -545,7 +719,7 @@ mixer_popup_show (MixerData *data)
 	gtk_window_set_screen (GTK_WINDOW (data->popup),
 			       gtk_widget_get_screen (data->applet));
 
-	data->vol_before_popup = readMixer ();
+	data->vol_before_popup = readMixer (data);
 	
 	frame = gtk_frame_new (NULL);
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 0);
@@ -571,8 +745,12 @@ mixer_popup_show (MixerData *data)
 				_("Volume Controller"),
 				_("Use Up/Down arrow keys to change volume"));
 	}
-	g_signal_connect (data->scale,
-			  "button-release-event",
+	/* This signal is to not let button press close the popup when the press is
+	** in the scale */
+	g_signal_connect_after (data->scale, "button_press_event",
+				  G_CALLBACK (scale_button_event), data);
+	g_signal_connect (data->popup,
+			  "button-press-event",
 			  (GCallback) scale_button_release_event_cb,
 			  data);
 
@@ -641,23 +819,23 @@ mixer_popup_show (MixerData *data)
 	/*
 	 * Grab focus and pointer.
 	 */
-	gtk_widget_grab_focus (data->scale);
-	gtk_grab_add (data->scale);
+	gtk_widget_grab_focus (data->popup);
+	gtk_grab_add (data->popup);
 
-	pointer = gdk_pointer_grab (data->scale->window,
+	pointer = gdk_pointer_grab (data->popup->window,
 				    TRUE,
-				    (GDK_BUTTON_PRESS_MASK
-				     | GDK_BUTTON_RELEASE_MASK
+				    (GDK_BUTTON_PRESS_MASK |
+				    GDK_BUTTON_RELEASE_MASK
 				     | GDK_POINTER_MOTION_MASK),
 				    NULL, NULL, GDK_CURRENT_TIME);
 	
-	keyboard = gdk_keyboard_grab (data->scale->window,
+	keyboard = gdk_keyboard_grab (data->popup->window,
 				      TRUE,
 				      GDK_CURRENT_TIME);
 	
 	if (pointer != GDK_GRAB_SUCCESS || keyboard != GDK_GRAB_SUCCESS) {
 		/* We could not grab. */
-		gtk_grab_remove (data->scale);
+		gtk_grab_remove (data->popup);
 		gtk_widget_destroy (data->popup);
 		data->popup = NULL;
 		data->scale = NULL;
@@ -698,7 +876,7 @@ mixer_popup_hide (MixerData *data, gboolean revert)
 
 		if (revert) {
 			vol = data->vol_before_popup;
-			setMixer (vol);
+			setMixer (vol, data);
 		} else {
 			/* Get a soft beep like sound to play here, like
 			 * on MacOS X :) */
@@ -716,7 +894,8 @@ destroy_mixer_cb (GtkWidget *widget, MixerData *data)
 		gtk_timeout_remove (data->timeout);
 		data->timeout = 0;
 	}
-	
+	if (data->error_dialog)
+		gtk_widget_destroy (data->error_dialog);
 	g_free (data);
 }
 
@@ -849,9 +1028,10 @@ mixer_help_cb (BonoboUIComponent *uic,
 {
         GError *error = NULL;
 
-	egg_screen_help_display (
+	egg_help_display_on_screen (
+		"mixer_applet2", NULL,
 		gtk_widget_get_screen (data->applet),
-		"mixer_applet2", NULL, &error);
+		&error);
 
 	if (error) { /* FIXME: the user needs to see this error */
 		g_print ("%s \n", error->message);
@@ -868,6 +1048,190 @@ mixer_mute_cb (BonoboUIComponent *uic,
 {
 }
 
+#ifdef OSS_API
+
+static gboolean
+cb_row_selected (GtkTreeSelection *selection, MixerData *data)
+{
+	PanelApplet *applet = PANEL_APPLET (data->applet);
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+	ChannelData *cdata;
+	
+	if (!gtk_tree_selection_get_selected (selection, &model, &iter)) 
+		return FALSE;
+		
+	gtk_tree_model_get (model, &iter, 1, &cdata, -1);
+	if (cdata->channel == data->mixerchannel)
+		return FALSE;		
+	
+	data->mixerchannel = cdata->channel;
+	panel_applet_gconf_set_int (applet, "channel", data->mixerchannel, NULL);
+}
+
+static void
+show_help_cb (GtkWindow *dialog)
+{
+	GError *error = NULL;
+	static GnomeProgram *applet_program = NULL;
+	
+	if (!applet_program) {
+		int argc = 1;
+		char *argv[2] = { "mixer_applet2" };
+		applet_program = gnome_program_init ("mixer_applet2", VERSION,
+						      LIBGNOME_MODULE, argc, argv,
+     						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
+	}
+
+	egg_help_display_desktop_on_screen (
+			applet_program, "mixer_applet2", "mixer_applet2", NULL,
+			gtk_widget_get_screen (GTK_WIDGET (dialog)),
+			&error);
+
+	if (error) {
+		GtkWidget *error_dialog;
+
+		error_dialog = gtk_message_dialog_new (
+				NULL,
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_MESSAGE_ERROR,
+				GTK_BUTTONS_CLOSE,
+				_("There was an error displaying help: %s"),
+				error->message);
+
+		g_signal_connect (error_dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_resizable (GTK_WINDOW (error_dialog), FALSE);
+		gtk_window_set_screen (GTK_WINDOW (error_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (dialog)));
+		gtk_widget_show (error_dialog);
+		g_error_free (error);
+	}
+}
+
+static void
+dialog_response (GtkDialog *dialog, gint id, MixerData *data)
+{
+	if (id == GTK_RESPONSE_HELP) {
+		show_help_cb (GTK_WINDOW (dialog));
+		return;
+	}
+	
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+	data->prefdialog = NULL;
+	
+}
+
+static void
+mixer_pref_cb (BonoboUIComponent *uic,
+	       MixerData         *data,
+	       const gchar       *verbname)
+{
+	GtkWidget *dialog;
+	GtkWidget *vbox, *vbox1, *vbox2, *vbox3;
+	GtkWidget *hbox, *hbox2;
+	GtkWidget *label;
+	GtkWidget *tree;
+	GtkListStore *model;
+	GtkWidget *scrolled;
+	GtkTreeViewColumn *column;
+	GtkCellRenderer *cell;
+	gchar *tmp;
+	GList *list = data->channels;
+	
+	if (data->prefdialog) {
+		gtk_window_present (GTK_WINDOW (data->prefdialog));
+		return;
+	}
+	
+	dialog = gtk_dialog_new_with_buttons (_("Volume Control Preferences"), NULL,
+                                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                   GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                                   GTK_STOCK_HELP, GTK_RESPONSE_HELP,
+                                                   NULL);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+	gtk_window_set_screen (GTK_WINDOW (dialog),
+                           gtk_widget_get_screen (GTK_WIDGET (data->applet)));
+        gtk_window_set_default_size (GTK_WINDOW (dialog), 300, 300);
+        data->prefdialog = dialog;
+                           
+	vbox = GTK_DIALOG (dialog)->vbox;
+	
+	vbox1 = gtk_vbox_new (FALSE, 18);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
+	gtk_box_pack_start (GTK_BOX (vbox), vbox1, TRUE, TRUE, 0);
+	
+	vbox2 = gtk_vbox_new (FALSE, 6);
+        gtk_box_pack_start (GTK_BOX (vbox1), vbox2, TRUE, TRUE, 0);
+        
+        tmp = g_strdup_printf ("<b>%s</b>", _("Audio Channels"));
+        label = gtk_label_new (NULL);
+        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+        gtk_label_set_markup (GTK_LABEL (label), tmp);
+        g_free (tmp);
+        gtk_box_pack_start (GTK_BOX (vbox2), label, FALSE, FALSE, 0);
+        
+        hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), hbox, TRUE, TRUE, 0);
+	
+	label = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	
+	vbox3 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox3, TRUE, TRUE, 0);
+	
+	label = gtk_label_new_with_mnemonic (_("_Select channel to control:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_box_pack_start (GTK_BOX (vbox3), label, FALSE, FALSE, 0);
+	
+	scrolled = gtk_scrolled_window_new(NULL,NULL);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
+						GTK_POLICY_AUTOMATIC,
+						GTK_POLICY_AUTOMATIC);
+	gtk_box_pack_start (GTK_BOX (vbox3), scrolled, TRUE, TRUE, 0);
+	
+	model = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
+	tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), tree);
+	gtk_container_add (GTK_CONTAINER (scrolled), tree);
+	g_object_unref (G_OBJECT (model));
+	cell = gtk_cell_renderer_text_new ();
+  	column = gtk_tree_view_column_new_with_attributes ("hello",
+						    	   cell,
+						     	   "text", 0,
+						     	   NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
+        gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tree), FALSE);
+        
+        while (list) {
+        	ChannelData *cdata = list->data;
+        	GtkTreeIter iter;
+        	
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, cdata->name, 1, cdata, -1);
+		if (cdata->channel == data->mixerchannel) {
+			GtkTreePath *path;
+			path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
+			gtk_tree_view_set_cursor (GTK_TREE_VIEW (tree), path, NULL, FALSE);
+		}
+        	list = g_list_next (list);
+        }
+        
+        g_signal_connect (G_OBJECT (gtk_tree_view_get_selection (GTK_TREE_VIEW (tree))), 
+			  	  "changed",
+			  	   G_CALLBACK (cb_row_selected), data);
+			  	   
+	g_signal_connect (G_OBJECT (dialog), "response",
+				  G_CALLBACK (dialog_response), data);
+        
+        gtk_widget_show_all (dialog);
+        
+}
+#endif
+
 static void
 mixer_ui_component_event (BonoboUIComponent            *comp,
 			  const gchar                  *path,
@@ -891,7 +1255,11 @@ mixer_ui_component_event (BonoboUIComponent            *comp,
 		data->mute = state;
 
 		if (data->mute) {
-			setMixer (0);
+#ifdef SUN_API
+			set_mute_status (TRUE);
+#else
+			setMixer (0, data);
+#endif
 			mixer_update_image (data);
 		
 				
@@ -906,7 +1274,11 @@ mixer_ui_component_event (BonoboUIComponent            *comp,
 			}
 		}
 		else {
-			setMixer (data->vol);
+#ifdef SUN_API
+			set_mute_status (FALSE);
+#else
+			setMixer (data->vol, data);
+#endif
 			mixer_update_image (data);
 			
 			
@@ -923,6 +1295,18 @@ mixer_ui_component_event (BonoboUIComponent            *comp,
 	}
 }
 
+static void
+get_prefs (MixerData *data)
+{
+	PanelApplet *applet = PANEL_APPLET (data->applet);
+	gint num;
+#ifdef OSS_API
+	num = panel_applet_gconf_get_int (applet, "channel", NULL);
+	num = CLAMP (num, 0,  SOUND_MIXER_NRDEVICES-1);	
+	data->mixerchannel = num;
+#endif
+}
+
 typedef struct
 {
 	char *stock_id;
@@ -965,6 +1349,9 @@ static void
 mixer_init_stock_icons ()
 {
 	GtkIconFactory *factory;
+	
+	if (icons_initialized)
+		return;
 
 	volume_icon_size = gtk_icon_size_register ("panel-menu", 
 						   VOLUME_DEFAULT_ICON_SIZE,
@@ -976,6 +1363,8 @@ mixer_init_stock_icons ()
 	register_mixer_stock_icons (factory);
 
 	g_object_unref (factory);
+
+	icons_initialized = TRUE;
 }
 
 const BonoboUIVerb mixer_applet_menu_verbs [] = {
@@ -983,13 +1372,15 @@ const BonoboUIVerb mixer_applet_menu_verbs [] = {
 	BONOBO_UI_UNSAFE_VERB ("Mute",     mixer_mute_cb),
 	BONOBO_UI_UNSAFE_VERB ("Help",     mixer_help_cb),
 	BONOBO_UI_UNSAFE_VERB ("About",    mixer_about_cb),
-	
+#ifdef OSS_API
+	BONOBO_UI_UNSAFE_VERB ("Pref",    mixer_pref_cb),
+#endif
         BONOBO_UI_VERB_END
 };
 
 static void
-applet_style_event_cb (GtkWidget *w, GtkStyle *prev_style, gpointer *user_data)
-{
+applet_style_event_cb (GtkWidget *w, GtkStyle *prev_style, MixerData *user_data)
+{	
 	mixer_load_volume_images (user_data);
 	mixer_update_image (user_data);
 }
@@ -1004,40 +1395,35 @@ mixer_applet_create (PanelApplet *applet)
 	gchar *ctl = NULL;
 #endif
 
+	data = g_new0 (MixerData, 1);
+	data->applet = GTK_WIDGET (applet);
+	
+	get_prefs (data);
+
 #ifdef OSS_API
 	/* /dev/sound/mixer for devfs */
 	device = "/dev/mixer";
-	retval = openMixer(device);
+	retval = openMixer(device, data);
 	if (!retval) {
 		device = "/dev/sound/mixer";
-		retval = openMixer (device);
+		retval = openMixer (device, data);
 	}
 #endif
 #ifdef SUN_API
 	if (!(ctl = g_getenv("AUDIODEV")))
 		ctl = "/dev/audio";
 	device = g_strdup_printf("%sctl",ctl);
-	retval = openMixer(device);
+	retval = openMixer(device, data);
 #endif
 	mixer_init_stock_icons ();
 	if (!retval) {
-		GtkWidget *dialog;
-		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-						 ("Couldn't open mixer device %s\n"),
-						 device, NULL);
-		gtk_window_set_screen (GTK_WINDOW (dialog),
-				       gtk_widget_get_screen (GTK_WIDGET (applet)));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
+		device_present = FALSE;
 	}
 
  	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(GTK_WIDGET(applet)))) {
 		gail_loaded = TRUE;
 	}
 
-	data = g_new0 (MixerData, 1);
-
 	/* Try to find some mixers - sdtaudiocontrol is on Solaris and is needed
 	** because gnome-volume-meter doesn't work */
 	if (run_mixer_cmd == NULL) 
@@ -1047,6 +1433,7 @@ mixer_applet_create (PanelApplet *applet)
 	if (run_mixer_cmd == NULL) 
 		run_mixer_cmd = g_find_program_in_path ("sdtaudiocontrol");
 	
+	data->device = g_strdup (device);
 	data->frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (data->frame), GTK_SHADOW_NONE);
 	gtk_container_add (GTK_CONTAINER (applet), data->frame);
@@ -1054,7 +1441,6 @@ mixer_applet_create (PanelApplet *applet)
 	data->image = gtk_image_new ();
 	gtk_container_add (GTK_CONTAINER (data->frame), data->image);
 
-	data->applet = GTK_WIDGET (applet);
 	mixer_load_volume_images (data);
 
         data->tooltips = gtk_tooltips_new ();                                   
@@ -1069,7 +1455,7 @@ mixer_applet_create (PanelApplet *applet)
 	} 
 	
 	g_signal_connect (data->applet,
-			  "button-release-event",
+			  "button-press-event",
 			  (GCallback) applet_button_release_event_cb,
 			  data);
 	
@@ -1102,7 +1488,7 @@ mixer_applet_create (PanelApplet *applet)
 			  data);
 
 	/* Get the initial volume. */
-	data->vol = readMixer ();
+	data->vol = readMixer (data);
 
 	/* Install timeout handler, that keeps the applet up-to-date if the
 	 * volume is changed somewhere else.
@@ -1148,6 +1534,10 @@ mixer_applet_create (PanelApplet *applet)
 
 	if (run_mixer_cmd == NULL)
 		bonobo_ui_component_rm (component, "/popups/popup/RunMixer", NULL);
+		
+#ifndef OSS_API
+	bonobo_ui_component_rm (component, "/popups/popup/Pref", NULL);
+#endif
 
 	applet_change_orient_cb (GTK_WIDGET (applet),
 				 panel_applet_get_orient (applet),
