@@ -78,7 +78,7 @@ about_cb (BonoboUIComponent *uic,
 	(_("System Monitor"), VERSION,
 	 "(C) 1999 - 2002 The Free Software Foundation",
 	 _("Released under the GNU General Public License.\n\n"
-	   "A system load monitor capable of displaying graphs for CPU, ram, and swap file use, plus network traffic."),
+	   "A system load monitor capable of displaying graphs for CPU, ram, and swap space use, plus network traffic."),
 	 authors,
 	 documenters,
 	 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
@@ -139,7 +139,7 @@ multiload_change_size_cb(PanelApplet *applet, gint size, gpointer data)
 	gint i;
 	MultiloadApplet *ma = (MultiloadApplet *)data;
 
-	for (i = 0; i < 5; i++) {
+	for (i = 0; i < NGRAPHS; i++) {
 		ma->graphs[i]->pixel_size = size;
   	  	if (ma->graphs[i]->orient) 
   	  		gtk_widget_set_size_request (ma->graphs[i]->main_widget, 
@@ -169,7 +169,7 @@ multiload_destroy_cb(GtkWidget *widget, gpointer data)
 	gint i;
 	MultiloadApplet *ma = data;
 	
-	for (i = 0; i < 5; i++)
+	for (i = 0; i < NGRAPHS; i++)
 	{
 		if (ma->graphs[i]->visible)
 		{
@@ -194,7 +194,7 @@ multiload_enter_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 
 	ma = (MultiloadApplet *)data;
 	
-	for (i = 0; i < 5; i++)
+	for (i = 0; i < NGRAPHS; i++)
 		if (ma->graphs[i]->visible)
 		{
 			ma->graphs[i]->tooltip_update = TRUE;
@@ -212,7 +212,7 @@ multiload_leave_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 
 	ma = (MultiloadApplet *)data;
 
-	for (i = 0; i < 5; i++)
+	for (i = 0; i < NGRAPHS; i++)
 		if (ma->graphs[i]->visible)
 			ma->graphs[i]->tooltip_update = FALSE;
 		
@@ -239,7 +239,9 @@ multiload_applet_tooltip_update(LoadGraph *g)
 	else if (!strncmp(g->name, "netload", strlen("netload")))
 		name = g_strdup(_("Network"));
 	else if (!strncmp(g->name, "swapload", strlen("swapload")))
-		name = g_strdup(_("Swap File"));
+		name = g_strdup(_("Swap Space"));
+	else if (!strncmp(g->name, "loadavg", strlen("loadavg")))
+		name = g_strdup(_("Load Average"));
 	else
 		name = g_strdup(_("Resource"));
 	
@@ -248,9 +250,7 @@ multiload_applet_tooltip_update(LoadGraph *g)
 	
 	for (i = 0; i < (g->n - 1); i++)
 		total_used += g->data[0][i];
-	/* netload has a fifth data structute */
-	if (!strncmp(g->name, "netload", strlen("netload")))
-		total_used += g->data[0][g->n - 1];	
+	
 	percent = 100 * (gdouble)total_used / (gdouble)g->draw_height;
 
 	tooltip_text = g_strdup_printf(_("%s:\n%d%% in use"), name, percent);
@@ -270,7 +270,7 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	PanelAppletOrient orientation;
 	
 	/* stop and free the old graphs */
-	for (i = 0; i < 5; i++)
+	for (i = 0; i < NGRAPHS; i++)
 	{
 		if (ma->graphs[i]->visible)
 		{
@@ -295,7 +295,7 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	
 	gtk_container_add(GTK_CONTAINER(ma->applet), ma->box);
 			
-	/* create the 5 graphs, passing in their user-configurable properties with gconf. */
+	/* create the NGRAPHS graphs, passing in their user-configurable properties with gconf. */
 	
 	ma->graphs[0] = cpuload_applet_new(ma->applet, NULL);
 	ma->graphs[1] = memload_applet_new(ma->applet, NULL);
@@ -305,7 +305,7 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	
 	/* only start and display the graphs the user has turned on */
 
-	for (i = 0; i < 5; i++) {
+	for (i = 0; i < NGRAPHS; i++) {
 	    gtk_box_pack_start(GTK_BOX(ma->box), 
 			       ma->graphs[i]->main_widget, 
 			       FALSE, FALSE, 1);
@@ -354,7 +354,7 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	
 	gtk_container_add(GTK_CONTAINER(applet), box);
 	
-	/* create the 5 graphs, passing in their user-configurable properties with gconf. */
+	/* create the NGRAPHS graphs, passing in their user-configurable properties with gconf. */
 	ma->graphs[0] = cpuload_applet_new(applet, NULL);
 	ma->graphs[1] = memload_applet_new(applet, NULL);
 	ma->graphs[2] = netload_applet_new(applet, NULL);
@@ -362,7 +362,7 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	ma->graphs[4] = loadavg_applet_new(applet, NULL);
 
 	/* only start and display the graphs the user has turned on */
-	for (i = 0; i < 5; i++) {
+	for (i = 0; i < NGRAPHS; i++) {
 	    gtk_box_pack_start(GTK_BOX(box), 
 			       ma->graphs[i]->main_widget, 
 			       FALSE, FALSE, 1);
